==> haskell-unliftio-0.2.10-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.10
id: unliftio-0.2.10-6BpS3bT3tbj8Fq9fxLSEC3
key: unliftio-0.2.10-6BpS3bT3tbj8Fq9fxLSEC3
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: 21c1aca4893d459b149a0c44d2f7c366
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.6.5/site-local/unliftio-0.2.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/unliftio-0.2.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/unliftio-0.2.10
hs-libraries: HSunliftio-0.2.10-6BpS3bT3tbj8Fq9fxLSEC3
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.5.0 stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.10-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.10
id: unliftio-0.2.10-1ahzAEOHVeJFpRZi3sy5hZ
key: unliftio-0.2.10-1ahzAEOHVeJFpRZi3sy5hZ
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: f07b080c673cc4bca57ec4e001f7a48c
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.6.5/site-local/unliftio-0.2.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/unliftio-0.2.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/unliftio-0.2.10
hs-libraries: HSunliftio-0.2.10-1ahzAEOHVeJFpRZi3sy5hZ
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.5.0 stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
